==> haskell-aeson-diff-1.1.0.7-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-aeson-diff.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aeson-diff
version: 1.1.0.7
id: aeson-diff-1.1.0.7-78B0HYeJ9GkF5NHe6f4FK7
key: aeson-diff-1.1.0.7-78B0HYeJ9GkF5NHe6f4FK7
license: BSD-3-Clause
copyright: (c) 2015 Thomas Sutton and others.
maintainer: me@thomas-sutton.id.au
author: Thomas Sutton
homepage: https://github.com/thsutton/aeson-diff
synopsis: Extract and apply patches to JSON documents.
description:
    .
    This is a small library for working with changes to JSON documents. It
    includes a library and two command-line executables in the style of the
    diff(1) and patch(1) commands available on many systems.
    .
category: JSON, Web, Algorithms
abi: 93b44d05a1fa461bd5d6e4bc5801a184
exposed: True
exposed-modules:
    Data.Aeson.Diff Data.Aeson.Patch Data.Aeson.Pointer
import-dirs: /usr/lib/ghc-8.6.5/site-local/aeson-diff-1.1.0.7
library-dirs: /usr/lib/ghc-8.6.5/site-local/aeson-diff-1.1.0.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/aeson-diff-1.1.0.7
hs-libraries: HSaeson-diff-1.1.0.7-78B0HYeJ9GkF5NHe6f4FK7
depends:
    aeson-1.4.3.0-5u6hknCeN6OEP5DlN5W0LL base-4.12.0.0
    bytestring-0.10.8.2
    edit-distance-vector-1.0.0.4-JJ22e9m60cFLGIHSxnibJc
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo mtl-2.2.2
    scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b text-1.2.3.1
    unordered-containers-0.2.10.0-KN3bhnJnJVDChkuCyIQcSr
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-aeson-diff/html/aeson-diff.haddock
haddock-html: /usr/share/doc/haskell-aeson-diff/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-diff-1.1.0.7-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-aeson-diff.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aeson-diff
version: 1.1.0.7
id: aeson-diff-1.1.0.7-Jq8iQh8MtcPKz2dghgdf47
key: aeson-diff-1.1.0.7-Jq8iQh8MtcPKz2dghgdf47
license: BSD-3-Clause
copyright: (c) 2015 Thomas Sutton and others.
maintainer: me@thomas-sutton.id.au
author: Thomas Sutton
homepage: https://github.com/thsutton/aeson-diff
synopsis: Extract and apply patches to JSON documents.
description:
    .
    This is a small library for working with changes to JSON documents. It
    includes a library and two command-line executables in the style of the
    diff(1) and patch(1) commands available on many systems.
    .
category: JSON, Web, Algorithms
abi: 4200f2a2a3c18a95fcf18e33e5083c9a
exposed: True
exposed-modules:
    Data.Aeson.Diff Data.Aeson.Patch Data.Aeson.Pointer
import-dirs: /usr/lib/ghc-8.6.5/site-local/aeson-diff-1.1.0.7
library-dirs: /usr/lib/ghc-8.6.5/site-local/aeson-diff-1.1.0.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/aeson-diff-1.1.0.7
hs-libraries: HSaeson-diff-1.1.0.7-Jq8iQh8MtcPKz2dghgdf47
depends:
    aeson-1.4.3.0-1l3nsKlFRrWAit5U2tQl5L base-4.12.0.0
    bytestring-0.10.8.2
    edit-distance-vector-1.0.0.4-AJbRhp4pAb32LJmZr1urGv
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo mtl-2.2.2
    scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b text-1.2.3.1
    unordered-containers-0.2.10.0-KN3bhnJnJVDChkuCyIQcSr
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-aeson-diff/html/aeson-diff.haddock
haddock-html: /usr/share/doc/haskell-aeson-diff/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
